pub enum AggregateSignatureError {
SerializationError,
BatchInvalid,
MissingSnarkAggregateVerificationKey,
MissingSnarkClerk,
UnsupportedProofSystem(AggregateSignatureType),
UnknownProofSystem(String),
}Expand description
Errors which can be output by Mithril aggregate verification.
Variants
SerializationError
This error occurs when the serialization of the raw bytes failed
BatchInvalid
Batch verification of STM aggregate signatures failed
MissingSnarkAggregateVerificationKey
Missing SNARK aggregate verification key
MissingSnarkClerk
Missing SNARK clerk for aggregate signature verification
UnsupportedProofSystem(AggregateSignatureType)
The proof system used in the aggregate signature is not supported
UnknownProofSystem(String)
The proof system is unknown