BlsSignatureError

Enum BlsSignatureError 

pub enum BlsSignatureError {
    SignatureInvalid(BlsSignature),
    AggregateSignatureInvalid,
    SerializationError,
    KeyInvalid(Box<BlsVerificationKeyProofOfPossession>),
    BatchInvalid,
    SignatureInfinity(BlsSignature),
    VerificationKeyInfinity(Box<BlsVerificationKey>),
}
Error types for multi signatures.

Variants



SignatureInvalid(BlsSignature)

Invalid Single signature



AggregateSignatureInvalid

Invalid aggregate signature



SerializationError

This error occurs when the serialization of the raw bytes failed



KeyInvalid(Box<BlsVerificationKeyProofOfPossession>)

Incorrect proof of possession



BatchInvalid

At least one signature in the batch is invalid



SignatureInfinity(BlsSignature)

Single signature is the infinity



VerificationKeyInfinity(Box<BlsVerificationKey>)

Verification key is the infinity