AggregateVerificationKey

Struct AggregateVerificationKey 

pub struct AggregateVerificationKey<D: MembershipDigest> { /* private fields */ }
Aggregate verification key combining both the concatenation and SNARK proof systems.

Holds the concatenation aggregate verification key used in the current Mithril protocol, and optionally the SNARK aggregate verification key when the future_snark feature is enabled.

Implementations

Source

impl<D: MembershipDigest> AggregateVerificationKey<D>

pub fn new( concatenation_aggregate_verification_key: AggregateVerificationKeyForConcatenation<D>, ) -> Self

Create a new aggregate verification key.

pub fn to_concatenation_aggregate_verification_key( &self, ) -> &AggregateVerificationKeyForConcatenation<D>

Returns the concatenation aggregate verification key.