Parameters

Struct Parameters 

pub struct Parameters {
    pub m: u64,
    pub k: u64,
    pub phi_f: PhiFValue,
}
Used to set protocol parameters.

Fields

m: u64

Security parameter, upper bound on indices.

k: u64

Quorum parameter.

phi_f: PhiFValue

f in phi(w) = 1 - (1 - f)^w, where w is the stake of a participant..

Implementations

Source

impl Parameters

pub fn to_bytes(&self) -> StmResult<Vec<u8>>

Convert to CBOR bytes with a version prefix.

Legacy readers that encounter the version prefix byte will fail gracefully, while new readers will decode the CBOR payload.

pub fn from_bytes(bytes: &[u8]) -> StmResult<Self>

Extract the Parameters from a byte slice.

Supports both the legacy big-endian byte format and the new versioned CBOR format.

Error

The function fails if the given string of bytes is not of required size.