pub struct RegistrationEntry(/* private fields */);Expand description
Represents a signer registration entry
Implementations
Sourceimpl RegistrationEntry
impl RegistrationEntry
Sourcepub fn new(
bls_verification_key_proof_of_possession: VerificationKeyProofOfPossessionForConcatenation,
stake: Stake,
) -> StmResult<Self>
pub fn new( bls_verification_key_proof_of_possession: VerificationKeyProofOfPossessionForConcatenation, stake: Stake, ) -> StmResult<Self>
Creates a new registration entry. Verifies the proof of possession of verification key for concatenation and validates the schnorr verification key before creating the entry.
Sourcepub fn get_verification_key_for_concatenation(
&self,
) -> VerificationKeyForConcatenation
pub fn get_verification_key_for_concatenation( &self, ) -> VerificationKeyForConcatenation
Gets the verification key for concatenation.