pub struct SingleSignature {
pub signer_index: SignerIndex,
/* private fields */
}Expand description
Single signature created by a single party who has won the lottery. Contains the underlying signature for the proof system and the registration index of the signer.
Fields
signer_index: SignerIndexMerkle tree index of the signer.
Implementations
Sourceimpl SingleSignature
impl SingleSignature
Sourcepub fn verify<D: MembershipDigest>(
&self,
params: &Parameters,
pk: &VerificationKeyForConcatenation,
stake: &Stake,
avk: &AggregateVerificationKey<D>,
msg: &[u8],
) -> StmResult<()>
pub fn verify<D: MembershipDigest>( &self, params: &Parameters, pk: &VerificationKeyForConcatenation, stake: &Stake, avk: &AggregateVerificationKey<D>, msg: &[u8], ) -> StmResult<()>
Verify a SingleSignature by validating the underlying single signature for proof system.
Sourcepub fn to_bytes(&self) -> StmResult<Vec<u8>>
pub fn to_bytes(&self) -> StmResult<Vec<u8>>
Convert a SingleSignature into bytes using CBOR encoding.
Sourcepub fn from_bytes<D: MembershipDigest>(
bytes: &[u8],
) -> StmResult<SingleSignature>
pub fn from_bytes<D: MembershipDigest>( bytes: &[u8], ) -> StmResult<SingleSignature>
Extract a SingleSignature from a byte slice.
Supports both CBOR-encoded (version-prefixed) and legacy manually packed formats.
Sourcepub fn get_concatenation_signature_indices(&self) -> Vec<LotteryIndex> ⓘ
pub fn get_concatenation_signature_indices(&self) -> Vec<LotteryIndex> ⓘ
Get indices of the single signature for concatenation proof system.
Sourcepub fn get_concatenation_signature_sigma(&self) -> BlsSignature
pub fn get_concatenation_signature_sigma(&self) -> BlsSignature
Get underlying BLS signature of the concatenation single signature.
Sourcepub fn set_concatenation_signature_indices(&mut self, indices: &[LotteryIndex])
pub fn set_concatenation_signature_indices(&mut self, indices: &[LotteryIndex])
Set the indices of the single signature for concatenation proof system.